@@ -8,7 +8,7 @@ use base 'Exporter';
 use Cwd;
 
 our @EXPORT = ('serve_directory_listing');
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 # FIXME: see  @{app->static->paths} for list of public directories
 our $public_dir = "public";
@@ -48,7 +48,11 @@ sub _serve_directory_listing {
 
     $caller->app->routes->get( $route, $listing_sub );
     $icon_server_set{$caller}++ or
-	$caller->app->routes->get( "/directory-listing-icons/#icon",
+	# route was  /directory-listing-icons/#icon
+	# but that was not compatible with some older libraries.
+	# :icon   is ok because we expect icon param to never
+	# contain '/' or '.'
+	$caller->app->routes->get( "/directory-listing-icons/:icon",
 				   \&_serve_icon );
 
     if ($options{recursive}) {
@@ -74,8 +78,13 @@ sub _serve_directory_listing {
     }
 
     if ($local) {
+	# route was  $route/#file  in 0.06, but that caused test
+	# failures on some systems, mainly with older Perl (but
+	# not necessarily older Mojolicious?)
 	$caller->app->routes->get( "$route/#file", 
 				   _mk_fileserver($local) );
+	$caller->app->routes->get( "$route/*file", 
+				   _mk_fileserver($local) );
     }
 }
 
@@ -401,7 +410,7 @@ MojoX::DirectoryListing - show Apache-style directory listings in your Mojolicio
 
 =head1 VERSION
 
-0.06
+0.07
 
 =head1 SYNOPSIS
 
@@ -691,7 +700,7 @@ L<Plack::App::Directory>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2013 Marty O'Brien.
+Copyright 2013-2016 Marty O'Brien.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
